BreakdownDimension enum
Dimension selector for the paginated breakdown endpoints.
The wireValue getter returns the string sent over the wire.
Values
- countries → const BreakdownDimension
-
Clicks grouped by country (wire:
"countries"). - referrers → const BreakdownDimension
-
Clicks grouped by full HTTP Referer value (wire:
"referrers"). - referrerHosts → const BreakdownDimension
-
Clicks grouped by referrer hostname (wire:
"referrer_hosts").
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
The wire-format string for this dimension.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BreakdownDimension> - A constant List of the values in this enum, in order of their declaration.