Bundle class
A collection of links grouped to show combined engagement.
- Implementers
- Annotations
-
- @immutable
Constructors
- Bundle({required int id, required String name, required String? description, required String? icon, required BundleAccent accent, required int? archivedAt, required String? createdVia, required String createdBy, required int createdAt, required int updatedAt})
-
Creates a bundle. Most callers should use Bundle.fromJson.
const
-
Bundle.fromJson(Map<
String, dynamic> json) -
Parses a bundle from its JSON representation.
factory
Properties
- accent → BundleAccent
-
Accent color applied to this bundle.
final
- archivedAt → int?
-
Unix seconds when the bundle was archived, or null if active.
final
- createdAt → int
-
Unix seconds when the bundle was created.
final
- createdBy → String
-
Identity (typically an email) of the creator.
final
- createdVia → String?
-
How the bundle was created. Null for legacy bundles.
final
- description → String?
-
Optional short description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Optional Material Symbol icon name.
final
- id → int
-
Unique bundle ID.
final
- name → String
-
Display name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → int
-
Unix seconds when the bundle was last modified.
final
Methods
-
copyWith(
{int? id, String? name, Object? description = _unset, Object? icon = _unset, BundleAccent? accent, Object? archivedAt = _unset, Object? createdVia = _unset, String? createdBy, int? createdAt, int? updatedAt}) → Bundle - Returns a copy with selected fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited