BundleAccent enum
Accent color applied to a bundle.
The wireValue getter returns the string sent over the wire. Use fromWire to parse a server response value.
Values
- orange → const BundleAccent
-
Orange accent.
- red → const BundleAccent
-
Red accent.
- green → const BundleAccent
-
Green accent.
- blue → const BundleAccent
-
Blue accent.
- purple → const BundleAccent
-
Purple accent.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
The wire-format string for this accent.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromWire(
String value) → BundleAccent - Parses a wire-format string into a BundleAccent.
Constants
-
values
→ const List<
BundleAccent> - A constant List of the values in this enum, in order of their declaration.