TimelineData class
Click timeline with bucketed counts and period summaries.
- Annotations
-
- @immutable
Constructors
-
TimelineData({required TimelineRange range, required List<
TimelineBucket> buckets, required TimelineSummary summary}) -
Creates a timeline data object. Most callers should use TimelineData.fromJson.
const
-
TimelineData.fromJson(Map<
String, dynamic> json) -
Parses a timeline data response from JSON.
factory
Properties
-
buckets
→ List<
TimelineBucket> -
Click counts bucketed over the range.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- range → TimelineRange
-
The time range this data covers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → TimelineSummary
-
Period summary totals.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited